PackagesCleanerCommand class

Command to manage and clean unused packages in Flutter projects

Constructors

PackagesCleanerCommand(Logger logger)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(ArgResults results) Future<void>
Execute the packages cleaner command
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited