ProcessUtils class

Constructors

ProcessUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getFlutterVersion() Future<String?>
isCommandAvailable(String command) Future<bool>
isDartAvailable() Future<bool>
isFlutterAvailable() Future<bool>
runCommand(String command, List<String> arguments, {Logger? logger, String? workingDirectory, bool showOutput = true}) Future<ProcessResult>
runDartCommand(List<String> arguments, {Logger? logger, String? workingDirectory, bool showOutput = true}) Future<ProcessResult>
runFlutterCommand(List<String> arguments, {Logger? logger, String? workingDirectory, bool showOutput = true}) Future<ProcessResult>